@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -189,7 +189,7 @@ class RESTList(RESTBase, Sequence):
     returned member of the list.
     """
 
-    _factory = lambda x: x  # flake8: noqa
+    _factory = lambda x: x  # noqa: E731
 
     @property
     def rest_data(self):
@@ -223,4 +223,4 @@ class RESTList(RESTBase, Sequence):
 
     def clear(self):
         self._connection.call(self._url, method='DELETE')
-        self._reset_cache()
\ No newline at end of file
+        self._reset_cache()
