@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -36,7 +36,8 @@ __all__ = [
 class MailingList(RESTObject):
 
     _properties = ('display_name', 'fqdn_listname', 'list_id', 'list_name',
-                   'mail_host', 'member_count', 'volume', 'self_link')
+                   'mail_host', 'member_count', 'volume', 'self_link',
+                   'description')
 
     def __init__(self, connection, url, data=None):
         super(MailingList, self).__init__(connection, url, data)
@@ -93,12 +94,13 @@ class MailingList(RESTObject):
         url = 'lists/{0}/roster/member'.format(self.fqdn_listname)
         return Page(self._connection, url, Member, count, page)
 
-    def find_members(self, address, role='member', page=None, count=50):
-        data = {
-            'subscriber': address,
-            'role': role,
-            'list_id': self.list_id,
-        }
+    def find_members(self, address=None, role=None, page=None, count=50):
+        data = {'list_id': self.list_id}
+        if address:
+            data['subscriber'] = address
+        if role:
+            data['role'] = role
+
         url = 'members/find?{}'.format(urlencode(data, doseq=True))
         if page is None:
             response, content = self._connection.call(url, data)
